Class: SmoochApi::IntegrationCreate

Inherits:
Object
  • Object
show all
Defined in:
lib/smooch-api/models/integration_create.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/smooch-api/models/integration_create.rb', line 143

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'pageAccessToken')
    self.page_access_token = attributes[:'pageAccessToken']
  end

  if attributes.has_key?(:'appId')
    self.app_id = attributes[:'appId']
  end

  if attributes.has_key?(:'appSecret')
    self.app_secret = attributes[:'appSecret']
  end

  if attributes.has_key?(:'accountSid')
    self. = attributes[:'accountSid']
  end

  if attributes.has_key?(:'authToken')
    self.auth_token = attributes[:'authToken']
  end

  if attributes.has_key?(:'phoneNumberSid')
    self.phone_number_sid = attributes[:'phoneNumberSid']
  end

  if attributes.has_key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.has_key?(:'channelAccessToken')
    self.channel_access_token = attributes[:'channelAccessToken']
  end

  if attributes.has_key?(:'encodingAesKey')
    self.encoding_aes_key = attributes[:'encodingAesKey']
  end

  if attributes.has_key?(:'fromAddress')
    self.from_address = attributes[:'fromAddress']
  end

  if attributes.has_key?(:'certificate')
    self.certificate = attributes[:'certificate']
  end

  if attributes.has_key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.has_key?(:'autoUpdateBadge')
    self.auto_update_badge = attributes[:'autoUpdateBadge']
  end

  if attributes.has_key?(:'serverKey')
    self.server_key = attributes[:'serverKey']
  end

  if attributes.has_key?(:'senderId')
    self.sender_id = attributes[:'senderId']
  end

  if attributes.has_key?(:'consumerKey')
    self.consumer_key = attributes[:'consumerKey']
  end

  if attributes.has_key?(:'consumerSecret')
    self.consumer_secret = attributes[:'consumerSecret']
  end

  if attributes.has_key?(:'accessTokenKey')
    self.access_token_key = attributes[:'accessTokenKey']
  end

  if attributes.has_key?(:'accessTokenSecret')
    self.access_token_secret = attributes[:'accessTokenSecret']
  end

  if attributes.has_key?(:'accessKey')
    self.access_key = attributes[:'accessKey']
  end

  if attributes.has_key?(:'originator')
    self.originator = attributes[:'originator']
  end

end

Instance Attribute Details

#access_keyObject

The public API key of your MessageBird account. Required for messagebird integrations.



79
80
81
# File 'lib/smooch-api/models/integration_create.rb', line 79

def access_key
  @access_key
end

#access_token_keyObject

The access token key obtained from your user via oauth. Required for twitter integrations.



73
74
75
# File 'lib/smooch-api/models/integration_create.rb', line 73

def access_token_key
  @access_token_key
end

#access_token_secretObject

The access token secret obtained from your user via oauth. Required for twitter integrations.



76
77
78
# File 'lib/smooch-api/models/integration_create.rb', line 76

def access_token_secret
  @access_token_secret
end

#account_sidObject

Twilio Account SID. Required for twilio integrations.



31
32
33
# File 'lib/smooch-api/models/integration_create.rb', line 31

def 
  @account_sid
end

#app_idObject

Facebook App ID OR WeChat App ID. Required for messenger and wechat integrations.



25
26
27
# File 'lib/smooch-api/models/integration_create.rb', line 25

def app_id
  @app_id
end

#app_secretObject

Facebook Page App Secret OR WeChat App Secret. Required for messenger and wechat integrations.



28
29
30
# File 'lib/smooch-api/models/integration_create.rb', line 28

def app_secret
  @app_secret
end

#auth_tokenObject

Twilio Auth Token. Required for twilio integrations.



34
35
36
# File 'lib/smooch-api/models/integration_create.rb', line 34

def auth_token
  @auth_token
end

#auto_update_badgeObject

Use the unread count of the conversation as the application badge. (Optional) Used for apn integrations.



58
59
60
# File 'lib/smooch-api/models/integration_create.rb', line 58

def auto_update_badge
  @auto_update_badge
end

#certificateObject

The binary of your APN certificate base64 encoded. Required for apn integrations.



52
53
54
# File 'lib/smooch-api/models/integration_create.rb', line 52

def certificate
  @certificate
end

#channel_access_tokenObject

LINE Channel Access Token. Required for line integrations.



43
44
45
# File 'lib/smooch-api/models/integration_create.rb', line 43

def channel_access_token
  @channel_access_token
end

#consumer_keyObject

The consumer key for your Twitter app. Required for twitter integrations.



67
68
69
# File 'lib/smooch-api/models/integration_create.rb', line 67

def consumer_key
  @consumer_key
end

#consumer_secretObject

The consumer secret for your Twitter app. Required for twitter integrations.



70
71
72
# File 'lib/smooch-api/models/integration_create.rb', line 70

def consumer_secret
  @consumer_secret
end

#encoding_aes_keyObject

AES Encoding Key. (Optional) Used for wechat integrations.



46
47
48
# File 'lib/smooch-api/models/integration_create.rb', line 46

def encoding_aes_key
  @encoding_aes_key
end

#from_addressObject

Email will display as coming from this address. (Optional) Used for frontendEmail integrations.



49
50
51
# File 'lib/smooch-api/models/integration_create.rb', line 49

def from_address
  @from_address
end

#originatorObject

Smooch will receive all messages sent to this phone number. Required for messagebird integrations.



82
83
84
# File 'lib/smooch-api/models/integration_create.rb', line 82

def originator
  @originator
end

#page_access_tokenObject

Facebook Page Access Token. Required for messenger integrations.



22
23
24
# File 'lib/smooch-api/models/integration_create.rb', line 22

def page_access_token
  @page_access_token
end

#passwordObject

The password for your APN certificate. (Optional) Used for apn integrations.



55
56
57
# File 'lib/smooch-api/models/integration_create.rb', line 55

def password
  @password
end

#phone_number_sidObject

SID for specific phone number. Required for twilio integrations.



37
38
39
# File 'lib/smooch-api/models/integration_create.rb', line 37

def phone_number_sid
  @phone_number_sid
end

#sender_idObject

Your sender id from the fcm console. Required for fcm integrations.



64
65
66
# File 'lib/smooch-api/models/integration_create.rb', line 64

def sender_id
  @sender_id
end

#server_keyObject

Your server key from the fcm console. Required for fcm integrations.



61
62
63
# File 'lib/smooch-api/models/integration_create.rb', line 61

def server_key
  @server_key
end

#tokenObject

Telegram Bot Token OR Viber Public Account token. Required for twilio and viber integrations.



40
41
42
# File 'lib/smooch-api/models/integration_create.rb', line 40

def token
  @token
end

#typeObject

The integration type.



19
20
21
# File 'lib/smooch-api/models/integration_create.rb', line 19

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/smooch-api/models/integration_create.rb', line 86

def self.attribute_map
  {
    :'type' => :'type',
    :'page_access_token' => :'pageAccessToken',
    :'app_id' => :'appId',
    :'app_secret' => :'appSecret',
    :'account_sid' => :'accountSid',
    :'auth_token' => :'authToken',
    :'phone_number_sid' => :'phoneNumberSid',
    :'token' => :'token',
    :'channel_access_token' => :'channelAccessToken',
    :'encoding_aes_key' => :'encodingAesKey',
    :'from_address' => :'fromAddress',
    :'certificate' => :'certificate',
    :'password' => :'password',
    :'auto_update_badge' => :'autoUpdateBadge',
    :'server_key' => :'serverKey',
    :'sender_id' => :'senderId',
    :'consumer_key' => :'consumerKey',
    :'consumer_secret' => :'consumerSecret',
    :'access_token_key' => :'accessTokenKey',
    :'access_token_secret' => :'accessTokenSecret',
    :'access_key' => :'accessKey',
    :'originator' => :'originator'
  }
end

.swagger_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/smooch-api/models/integration_create.rb', line 114

def self.swagger_types
  {
    :'type' => :'String',
    :'page_access_token' => :'String',
    :'app_id' => :'String',
    :'app_secret' => :'String',
    :'account_sid' => :'String',
    :'auth_token' => :'String',
    :'phone_number_sid' => :'String',
    :'token' => :'String',
    :'channel_access_token' => :'String',
    :'encoding_aes_key' => :'String',
    :'from_address' => :'String',
    :'certificate' => :'String',
    :'password' => :'String',
    :'auto_update_badge' => :'BOOLEAN',
    :'server_key' => :'String',
    :'sender_id' => :'String',
    :'consumer_key' => :'String',
    :'consumer_secret' => :'String',
    :'access_token_key' => :'String',
    :'access_token_secret' => :'String',
    :'access_key' => :'String',
    :'originator' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/smooch-api/models/integration_create.rb', line 259

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      page_access_token == o.page_access_token &&
      app_id == o.app_id &&
      app_secret == o.app_secret &&
       == o. &&
      auth_token == o.auth_token &&
      phone_number_sid == o.phone_number_sid &&
      token == o.token &&
      channel_access_token == o.channel_access_token &&
      encoding_aes_key == o.encoding_aes_key &&
      from_address == o.from_address &&
      certificate == o.certificate &&
      password == o.password &&
      auto_update_badge == o.auto_update_badge &&
      server_key == o.server_key &&
      sender_id == o.sender_id &&
      consumer_key == o.consumer_key &&
      consumer_secret == o.consumer_secret &&
      access_token_key == o.access_token_key &&
      access_token_secret == o.access_token_secret &&
      access_key == o.access_key &&
      originator == o.originator
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/smooch-api/models/integration_create.rb', line 322

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = SmoochApi.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/smooch-api/models/integration_create.rb', line 388

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/smooch-api/models/integration_create.rb', line 301

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


288
289
290
# File 'lib/smooch-api/models/integration_create.rb', line 288

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



294
295
296
# File 'lib/smooch-api/models/integration_create.rb', line 294

def hash
  [type, page_access_token, app_id, app_secret, , auth_token, phone_number_sid, token, channel_access_token, encoding_aes_key, from_address, certificate, password, auto_update_badge, server_key, sender_id, consumer_key, consumer_secret, access_token_key, access_token_secret, access_key, originator].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



241
242
243
244
245
246
247
248
# File 'lib/smooch-api/models/integration_create.rb', line 241

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push("invalid value for 'type', type cannot be nil.")
  end

  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
# File 'lib/smooch-api/models/integration_create.rb', line 368

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
377
378
379
380
381
382
# File 'lib/smooch-api/models/integration_create.rb', line 374

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



362
363
364
# File 'lib/smooch-api/models/integration_create.rb', line 362

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



252
253
254
255
# File 'lib/smooch-api/models/integration_create.rb', line 252

def valid?
  return false if @type.nil?
  return true
end