Class: SmoochApi::IntegrationCreate
- Inherits:
-
Object
- Object
- SmoochApi::IntegrationCreate
- Defined in:
- lib/smooch-api/models/integration_create.rb
Instance Attribute Summary collapse
-
#account_sid ⇒ Object
Twilio Account SID.
-
#app_id ⇒ Object
Facebook App ID OR WeChat App ID.
-
#app_secret ⇒ Object
Facebook Page App Secret OR WeChat App Secret.
-
#auth_token ⇒ Object
Twilio Auth Token.
-
#auto_update_badge ⇒ Object
Use the unread count of the conversation as the application badge.
-
#certificate ⇒ Object
The binary of your APN certificate base64 encoded.
-
#channel_access_token ⇒ Object
LINE Channel Access Token.
-
#encoding_aes_key ⇒ Object
AES Encoding Key.
-
#from_address ⇒ Object
Email will display as coming from this address.
-
#page_access_token ⇒ Object
Facebook Page Access Token.
-
#password ⇒ Object
The password for your APN certificate.
-
#phone_number_sid ⇒ Object
SID for specific phone number.
-
#sender_id ⇒ Object
Your sender id from the fcm console.
-
#server_key ⇒ Object
Your server key from the fcm console.
-
#token ⇒ Object
Telegram Bot Token OR Viber Public Account token.
-
#type ⇒ Object
The integration type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationCreate
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/smooch-api/models/integration_create.rb', line 112 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'pageAccessToken') self.page_access_token = attributes[:'pageAccessToken'] end if attributes.has_key?(:'appId') self.app_id = attributes[:'appId'] end if attributes.has_key?(:'appSecret') self.app_secret = attributes[:'appSecret'] end if attributes.has_key?(:'accountSid') self.account_sid = attributes[:'accountSid'] end if attributes.has_key?(:'authToken') self.auth_token = attributes[:'authToken'] end if attributes.has_key?(:'phoneNumberSid') self.phone_number_sid = attributes[:'phoneNumberSid'] end if attributes.has_key?(:'token') self.token = attributes[:'token'] end if attributes.has_key?(:'channelAccessToken') self.channel_access_token = attributes[:'channelAccessToken'] end if attributes.has_key?(:'encodingAesKey') self.encoding_aes_key = attributes[:'encodingAesKey'] end if attributes.has_key?(:'fromAddress') self.from_address = attributes[:'fromAddress'] end if attributes.has_key?(:'certificate') self.certificate = attributes[:'certificate'] end if attributes.has_key?(:'password') self.password = attributes[:'password'] end if attributes.has_key?(:'autoUpdateBadge') self.auto_update_badge = attributes[:'autoUpdateBadge'] end if attributes.has_key?(:'serverKey') self.server_key = attributes[:'serverKey'] end if attributes.has_key?(:'senderId') self.sender_id = attributes[:'senderId'] end end |
Instance Attribute Details
#account_sid ⇒ Object
Twilio Account SID. Required for twilio integrations.
30 31 32 |
# File 'lib/smooch-api/models/integration_create.rb', line 30 def account_sid @account_sid end |
#app_id ⇒ Object
Facebook App ID OR WeChat App ID. Required for messenger and wechat integrations.
24 25 26 |
# File 'lib/smooch-api/models/integration_create.rb', line 24 def app_id @app_id end |
#app_secret ⇒ Object
Facebook Page App Secret OR WeChat App Secret. Required for messenger and wechat integrations.
27 28 29 |
# File 'lib/smooch-api/models/integration_create.rb', line 27 def app_secret @app_secret end |
#auth_token ⇒ Object
Twilio Auth Token. Required for twilio integrations.
33 34 35 |
# File 'lib/smooch-api/models/integration_create.rb', line 33 def auth_token @auth_token end |
#auto_update_badge ⇒ Object
Use the unread count of the conversation as the application badge. (Optional) Used for apn integrations.
57 58 59 |
# File 'lib/smooch-api/models/integration_create.rb', line 57 def auto_update_badge @auto_update_badge end |
#certificate ⇒ Object
The binary of your APN certificate base64 encoded. Required for apn integrations.
51 52 53 |
# File 'lib/smooch-api/models/integration_create.rb', line 51 def certificate @certificate end |
#channel_access_token ⇒ Object
LINE Channel Access Token. Required for line integrations.
42 43 44 |
# File 'lib/smooch-api/models/integration_create.rb', line 42 def channel_access_token @channel_access_token end |
#encoding_aes_key ⇒ Object
AES Encoding Key. (Optional) Used for wechat integrations.
45 46 47 |
# File 'lib/smooch-api/models/integration_create.rb', line 45 def encoding_aes_key @encoding_aes_key end |
#from_address ⇒ Object
Email will display as coming from this address. (Optional) Used for frontendEmail integrations.
48 49 50 |
# File 'lib/smooch-api/models/integration_create.rb', line 48 def from_address @from_address end |
#page_access_token ⇒ Object
Facebook Page Access Token. Required for messenger integrations.
21 22 23 |
# File 'lib/smooch-api/models/integration_create.rb', line 21 def page_access_token @page_access_token end |
#password ⇒ Object
The password for your APN certificate. (Optional) Used for apn integrations.
54 55 56 |
# File 'lib/smooch-api/models/integration_create.rb', line 54 def password @password end |
#phone_number_sid ⇒ Object
SID for specific phone number. Required for twilio integrations.
36 37 38 |
# File 'lib/smooch-api/models/integration_create.rb', line 36 def phone_number_sid @phone_number_sid end |
#sender_id ⇒ Object
Your sender id from the fcm console. Required for fcm integrations.
63 64 65 |
# File 'lib/smooch-api/models/integration_create.rb', line 63 def sender_id @sender_id end |
#server_key ⇒ Object
Your server key from the fcm console. Required for fcm integrations.
60 61 62 |
# File 'lib/smooch-api/models/integration_create.rb', line 60 def server_key @server_key end |
#token ⇒ Object
Telegram Bot Token OR Viber Public Account token. Required for twilio and viber integrations.
39 40 41 |
# File 'lib/smooch-api/models/integration_create.rb', line 39 def token @token end |
#type ⇒ Object
The integration type.
18 19 20 |
# File 'lib/smooch-api/models/integration_create.rb', line 18 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/smooch-api/models/integration_create.rb', line 67 def self.attribute_map { :'type' => :'type', :'page_access_token' => :'pageAccessToken', :'app_id' => :'appId', :'app_secret' => :'appSecret', :'account_sid' => :'accountSid', :'auth_token' => :'authToken', :'phone_number_sid' => :'phoneNumberSid', :'token' => :'token', :'channel_access_token' => :'channelAccessToken', :'encoding_aes_key' => :'encodingAesKey', :'from_address' => :'fromAddress', :'certificate' => :'certificate', :'password' => :'password', :'auto_update_badge' => :'autoUpdateBadge', :'server_key' => :'serverKey', :'sender_id' => :'senderId' } end |
.swagger_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/smooch-api/models/integration_create.rb', line 89 def self.swagger_types { :'type' => :'String', :'page_access_token' => :'String', :'app_id' => :'String', :'app_secret' => :'String', :'account_sid' => :'String', :'auth_token' => :'String', :'phone_number_sid' => :'String', :'token' => :'String', :'channel_access_token' => :'String', :'encoding_aes_key' => :'String', :'from_address' => :'String', :'certificate' => :'String', :'password' => :'String', :'auto_update_badge' => :'BOOLEAN', :'server_key' => :'String', :'sender_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/smooch-api/models/integration_create.rb', line 204 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && page_access_token == o.page_access_token && app_id == o.app_id && app_secret == o.app_secret && account_sid == o.account_sid && auth_token == o.auth_token && phone_number_sid == o.phone_number_sid && token == o.token && channel_access_token == o.channel_access_token && encoding_aes_key == o.encoding_aes_key && from_address == o.from_address && certificate == o.certificate && password == o.password && auto_update_badge == o.auto_update_badge && server_key == o.server_key && sender_id == o.sender_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/smooch-api/models/integration_create.rb', line 261 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = SmoochApi.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/smooch-api/models/integration_create.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/smooch-api/models/integration_create.rb', line 240 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/smooch-api/models/integration_create.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/smooch-api/models/integration_create.rb', line 233 def hash [type, page_access_token, app_id, app_secret, account_sid, auth_token, phone_number_sid, token, channel_access_token, encoding_aes_key, from_address, certificate, password, auto_update_badge, server_key, sender_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
186 187 188 189 190 191 192 193 |
# File 'lib/smooch-api/models/integration_create.rb', line 186 def list_invalid_properties invalid_properties = Array.new if @type.nil? invalid_properties.push("invalid value for 'type', type cannot be nil.") end return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
307 308 309 |
# File 'lib/smooch-api/models/integration_create.rb', line 307 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 |
# File 'lib/smooch-api/models/integration_create.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
301 302 303 |
# File 'lib/smooch-api/models/integration_create.rb', line 301 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 |
# File 'lib/smooch-api/models/integration_create.rb', line 197 def valid? return false if @type.nil? return true end |